@@ -98,7 +98,7 @@ void AddDel::init()
   set_prevent_user_signals();
   set_ignore_treeview_signals();
 
-  set_spacing(6);
+  set_spacing(Utils::DEFAULT_SPACING_SMALL);
 
   m_bAllowUserActions = true;
 
@@ -1617,8 +1617,9 @@ bool AddDel::row_has_duplicates(const Gtk::TreeModel::iterator& iter) const
     {
       Gtk::TreeModel::Row row = *iter;
 
-      //We can't just use ValueBase, because Glib::ValueBase has no operator==, because there is no g_value_equal
-      //Glib::ValueBase value_this_row;
+      //We can't just use Value, because Gnome::Gda::Value has no operator==, because there is no g_value_equal
+      //Gnome::Gda::Value value_this_row;
+      //TODO: Actually, Gnome::Gda::Value has an operator==
       //iter->get_value(col, value_this_row);
 
       Glib::ustring value_text;
@@ -1640,8 +1641,9 @@ bool AddDel::row_has_duplicates(const Gtk::TreeModel::iterator& iter) const
         if(iterCheck != iter) //Don't compare the row with itself
         {
           Gtk::TreeModel::Row check_row = *iterCheck;
-          ////Glib::ValueBase has no operator==, because there is no g_value_equal
-          //Glib::ValueBase value_check_row;
+          ////Gnome::Gda::Value has no operator==, because there is no g_value_equal
+          //Gnome::Gda::Value value_check_row;
+          //TODO: Actually, Gnome::Gda::Value has an operator==
           //iterCheck->get_value(col, value_check_row);
           //
           //if(value_check_row == value_this_row)
